@@ -6,12 +6,14 @@ import sys
 def main():
     """Console script for astrophysics_toolset."""
     parser = argparse.ArgumentParser()
-    parser.add_argument('_', nargs='*')
+    parser.add_argument("_", nargs="*")
     args = parser.parse_args()
 
     print("Arguments: " + str(args._))
-    print("Replace this message by putting your code into "
-          "astrophysics_toolset.cli.main")
+    print(
+        "Replace this message by putting your code into "
+        "astrophysics_toolset.cli.main"
+    )
     return 0
 
 
