@@ -1,16 +1,17 @@
 """Useful decorators."""
 
+import os
 from functools import wraps
 from typing import Callable
-import os
+
 import numpy as np
 
 from .exceptions import AstroToolsetNotSpatialError
 
 
-class read_files():
+class read_files:
     """Decorator for functions that take a file as input.
-    
+
     Parameters:
     -----------
     N : int
@@ -18,20 +19,22 @@ class read_files():
 
     Notes
     -----
-    The wrapped function is expected to have its input files as first arguments.
+    The wrapped function is expected to have its input files as last argument.
     """
+
     N_files = 0
 
-    def __init__(self, N : int):
+    def __init__(self, N: int):
         self.N_files = N
 
-    def __call__(self, fun : Callable) -> Callable:
+    def __call__(self, fun: Callable) -> Callable:
         @wraps(fun)
         def wrapped(*args, **kwargs):
+            nargs = len(args)
             for i in range(self.N_files):
-                if not os.path.exists(args[i]):
-                    raise FileNotFoundError(args[i])
-            
+                if not os.path.exists(args[nargs - i - 1]):
+                    raise FileNotFoundError(args[nargs - i - 1])
+
             return fun(*args, **kwargs)
 
         return wrapped
@@ -52,4 +55,4 @@ def spatial(fun):
             raise AstroToolsetNotSpatialError(spatial_array)
         return fun(spatial_array, *args, **kwargs)
 
-    return wrapped
\ No newline at end of file
+    return wrapped
